@@ -233,7 +233,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action       # type: ignore
 
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 
 
 FLOW_PATH_ROOT_ID = '<<<root>>>'     #: needed for flow path jumper and for drop onto leave item button
@@ -369,11 +369,11 @@ class LiszDataMixin(ABC):
                 nid['id'] = new_id
             if want_node is not None and want_node != ('node' in nid):  # NOTE: != has lower priority than in operator
                 if want_node:
-                    nid['node'] = list()        # type: ignore   # mypy not supports recursive types see issue #731
-                elif nid['node']:       # let user confirm node deletion of non-empty nid['node']
+                    nid['node'] = list()    # type: ignore   # mypy not supports recursive types see issue #731
+                elif nid['node']:           # let user confirm node deletion of non-empty nid['node']
                     return 'request_delete_confirmation_for_node'
                 else:
-                    nid.pop('node')     # remove empty node
+                    nid.pop('node')         # remove empty node
 
         if toggle_sel:
             self.toggle_item_sel(new_idx)
@@ -425,17 +425,18 @@ class LiszDataMixin(ABC):
         :param text:            flow path text - like returned by :meth:`~LiszDataMixin.flow_path_text`.
         :return:                flow path list.
         """
-        path_nid = None         # suppress Pycharm PyUnboundLocalVariable inspection warning
         flow_path = list()
         if text != FLOW_PATH_ROOT_ID:
             node = self.root_node
             for part in text.split(FLOW_PATH_TEXT_SEP):
                 for nid in node:
                     if nid['id'].startswith(part) and 'node' in nid:
-                        part = nid['id']
+                        flo_key = nid['id']
                         path_nid = nid
                         break
-                flow_path.append(id_of_flow('enter', 'item', part))
+                else:
+                    break       # actually not needed, will repair data tree errors
+                flow_path.append(id_of_flow('enter', 'item', flo_key))
                 node = path_nid['node']         # type: ignore   # mypy not supports recursive types see issue #731
         return flow_path
 
@@ -452,7 +453,10 @@ class LiszDataMixin(ABC):
             if flow_action(flow_id) != 'enter':
                 break
             node_id = flow_key(flow_id)
-            current_node_items = self.item_by_id(node_id, searched_node=current_node_items)['node']
+            item = self.item_by_id(node_id, searched_node=current_node_items)
+            if 'node' not in item:
+                break                           # actually not needed, will repair broken flow path
+            current_node_items = item['node']
         return current_node_items
 
     def flow_path_quick_jump_nodes(self):
@@ -468,11 +472,11 @@ class LiszDataMixin(ABC):
 
         paths = [FLOW_PATH_ROOT_ID] if self.flow_path_action(0) == 'enter' else list()
         deep = 0
-        while deep < len(self.flow_path) and self.flow_path_action(deep) == 'enter':
+        while deep < len(self.flow_path) - 1 and self.flow_path_action(deep + 1) == 'enter':
             deep += 1
             paths.append(self.flow_path_text(self.flow_path[:deep]))
 
-        deeper_flow_path = self.flow_path[:deep]
+        deeper_flow_path = self.flow_path[:-1]      # start at current flow path minus the open_flow_path_jumper flow id
         append_nodes(self.current_node_items)
 
         return paths
@@ -495,15 +499,14 @@ class LiszDataMixin(ABC):
             sub_id_len = len(node_id)
             for nid in node:
                 if nid['id'] == node_id:
-                    assert 'node' in nid
                     path_nid = nid
                 elif 'node' in nid:
                     while nid['id'].startswith(node_id[:id_len]) and id_len < sub_id_len:
                         id_len += 1
 
             shortened_ids.append(node_id[:id_len])
-            if path_nid:                        # prevent error in quick jump to root
-                node = path_nid['node']         # type: ignore   # mypy not supports recursive types see issue #731
+            if path_nid and 'node' in path_nid:     # prevent error in quick jump to root
+                node = path_nid['node']             # type: ignore   # mypy not supports recursive types see issue #731
 
         return FLOW_PATH_TEXT_SEP.join(shortened_ids)
 
@@ -603,6 +606,13 @@ class LiszDataMixin(ABC):
         :param key_code:        key code string.
         :return:                True if key event got processed/used, else False.
         """
+        if key_code == 'r':
+            if modifiers == 'Shift':
+                self.change_app_state('flow_path', [])  # quick jump to root (also repairing any flow path errors)
+                self.change_app_state('flow_id', '')
+            self.refresh_all()
+            return True
+
         if modifiers or flow_action(self.flow_id) not in ('', 'focus'):
             return False
 
@@ -641,9 +651,6 @@ class LiszDataMixin(ABC):
         elif key_code in ('-', 'del') and flo_key:
             self.change_flow(id_of_flow('confirm', 'item_deletion', flo_key))
 
-        elif key_code == 'r':
-            self.refresh_all()
-
         else:
             return False    # pressed key not processable in the current flow/app-state
 
